"use strict";
/*
 * Copyright © 2019 Atomist, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const automation_client_1 = require("@atomist/automation-client");
const _ = require("lodash");
const types_1 = require("../typings/types");
const utils_1 = require("../util/utils");
function deleteWebhook(graphClient, id) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            yield graphClient.mutate({
                name: "DeleteWebhook",
                variables: {
                    id,
                },
            });
        }
        catch (e) {
            automation_client_1.logger.warn(`Failed to delete webhook with id '${id}'`);
        }
    });
}
exports.deleteWebhook = deleteWebhook;
function createWebhook(graphClient, provider, tag) {
    return __awaiter(this, void 0, void 0, function* () {
        const secret = utils_1.nonce(50);
        return {
            webhook: (yield graphClient.mutate({
                name: "CreateWebhook",
                variables: {
                    header: "X-Hub-Signature",
                    resourceProviderId: provider.id,
                    name: `Atomist`,
                    secret,
                    tags: [{
                            name: tag.name,
                            value: tag.value,
                        }],
                },
            })).createWebhook, secret,
        };
    });
}
exports.createWebhook = createWebhook;
function addWebhookTag(graphClient, webhook, tag) {
    return __awaiter(this, void 0, void 0, function* () {
        yield graphClient.mutate({
            name: "AddWebhookTag",
            variables: {
                id: webhook.id,
                name: tag.name,
                value: tag.value,
            },
        });
    });
}
exports.addWebhookTag = addWebhookTag;
function setProviderState(graphClient, provider, state = types_1.ScmProviderStateName.converged, errors) {
    return __awaiter(this, void 0, void 0, function* () {
        const newError = (errors || []).sort((e1, e2) => e1.localeCompare(e2)).join(", ");
        const currentState = _.get(provider, "state.name");
        const currentError = _.get(provider, "state.error");
        if (state !== currentState || newError !== currentError) {
            yield graphClient.mutate({
                name: "SetScmProviderState",
                variables: {
                    id: provider.id,
                    state,
                    error: newError,
                },
            });
        }
    });
}
exports.setProviderState = setProviderState;
function loadProvider(graphClient, id) {
    return __awaiter(this, void 0, void 0, function* () {
        return (yield graphClient.query({
            name: "ScmProviderById",
            variables: {
                id,
            },
            options: automation_client_1.QueryNoCacheOptions,
        })).SCMProvider[0];
    });
}
exports.loadProvider = loadProvider;
//# sourceMappingURL=api.js.map