import { ExtensionPack } from "@atomist/sdm";
import { ProviderType } from "../typings/types";
/**
 * Configuration options for the GitHub RCCA
 */
export interface ConvergenceOptions {
    /**
     * Interval in ms of convergence runs
     * If not value is provided here, configuration is checked at 'sdm.converge.github.interval'
     */
    interval?: number;
    /**
     * Provider type to converge for
     * If not value is provided here, configuration is checked at 'sdm.converge.github.providerType'
     */
    providerType?: ProviderType.github_com | ProviderType.ghe;
    /**
     * Additional events that can trigger convergence
     */
    events?: {
        /**
         * Generated repos via one of your SDM generators should get a repo webhook
         */
        repoGenerated?: boolean;
    };
}
/**
 * GitHub RCCA Extension Pack to manage webhook resources on GitHub.com or on-prem GHE
 * @param options
 */
export declare function convergeGitHub(options?: ConvergenceOptions): ExtensionPack;
