"use strict";
/*
 * Copyright © 2019 Atomist, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const automation_client_1 = require("@atomist/automation-client");
const sdm_1 = require("@atomist/sdm");
const _ = require("lodash");
const types_1 = require("../typings/types");
const converge_1 = require("./converge");
const repo_1 = require("./repo");
/**
 * GitHub RCCA Extension Pack to manage webhook resources on GitHub.com or on-prem GHE
 * @param options
 */
function convergeGitHub(options = {}) {
    return Object.assign({}, sdm_1.metadata("converge"), { configure: sdm => {
            const optsToUse = Object.assign({ interval: _.get(sdm, "configuration.sdm.converge.github.interval", 1000 * 60 * 10), providerType: _.get(sdm, "configuration.sdm.converge.github.providerType", types_1.ProviderType.github_com), events: _.get(sdm, "configuration.sdm.converge.github.events", { repoGenerated: false }) }, options);
            const converge = (l) => __awaiter(this, void 0, void 0, function* () {
                for (const workspaceId of sdm.configuration.workspaceIds) {
                    yield converge_1.convergeWorkspace(workspaceId, sdm, optsToUse);
                }
            });
            if (!!sdm.configuration.workspaceIds && sdm.configuration.workspaceIds.length > 0) {
                sdm.addTriggeredListener({
                    listener: converge,
                    trigger: {
                        interval: optsToUse.interval,
                    },
                });
                sdm.addStartupListener(converge);
            }
            if (_.get(optsToUse, "events.repoGenerated") === true) {
                sdm.addEvent(repo_1.ConvergeRepoOnRepoProvenance);
            }
            sdm.addEvent(onScmProviderHandler(optsToUse));
        } });
}
exports.convergeGitHub = convergeGitHub;
/**
 * EventHandlerRegistration listening for new SCMProvider events and triggering the convergence function
 */
function onScmProviderHandler(options) {
    return {
        name: "ConvergeGitHubOnScmProvider",
        subscription: automation_client_1.GraphQL.subscription({
            name: "OnScmProvider",
            variables: {
                type: automation_client_1.GraphQL.enumValue(options.providerType),
            },
        }),
        description: "Converge on GitHub ScmProvider events",
        listener: (e, ctx) => __awaiter(this, void 0, void 0, function* () {
            const providers = e.data;
            return converge_1.convergeProvider(providers.SCMProvider[0], ctx.graphClient);
        }),
    };
}
//# sourceMappingURL=convergeGitHub.js.map