"use strict";
/*
 * Copyright © 2019 Atomist, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const automation_client_1 = require("@atomist/automation-client");
const github = require("@octokit/rest");
const api_1 = require("./api");
function createOrgWebhook(org, provider, token, graphClient) {
    return __awaiter(this, void 0, void 0, function* () {
        const cw = yield api_1.createWebhook(graphClient, provider, { name: "org", value: org });
        const webhook = yield gitHub(token, provider).orgs.createHook({
            active: true,
            name: "web",
            events: ["*"],
            org,
            config: {
                content_type: "json",
                secret: cw.secret,
                url: cw.webhook.url,
            },
        });
        const hookId = webhook.data.id;
        yield api_1.addWebhookTag(graphClient, cw.webhook, { name: "hook_id", value: hookId.toString() });
        automation_client_1.logger.debug(`Created new webhook for GitHub org ${org} with hook_id '${hookId}' and url '${cw.webhook.url}'`);
    });
}
exports.createOrgWebhook = createOrgWebhook;
function createRepoWebhook(owner, repo, provider, token, graphClient) {
    return __awaiter(this, void 0, void 0, function* () {
        const slug = `${owner}/${repo}`;
        const cw = yield api_1.createWebhook(graphClient, provider, { name: "repo", value: slug });
        const webhook = yield gitHub(token, provider).repos.createHook({
            active: true,
            name: "web",
            events: ["*"],
            owner,
            repo,
            config: {
                content_type: "json",
                secret: cw.secret,
                url: cw.webhook.url,
            },
        });
        const hookId = webhook.data.id;
        yield api_1.addWebhookTag(graphClient, cw.webhook, { name: "hook_id", value: hookId.toString() });
        automation_client_1.logger.debug(`Created new webhook for GitHub repo ${slug} with hook_id '${hookId}' and url '${cw.webhook.url}'`);
    });
}
exports.createRepoWebhook = createRepoWebhook;
function gitHub(token, provider) {
    const apiUrl = new URL(provider.apiUrl);
    const api = new github({
        auth: `token ${token}`,
        protocol: apiUrl.protocol,
        host: apiUrl.host,
        port: +apiUrl.port,
        pathPrefix: apiUrl.pathname,
    });
    return api;
}
exports.gitHub = gitHub;
function isAuthError(error) {
    if (!!error && !!error.status && error.status === 401) {
        return true;
    }
    else {
        return false;
    }
}
exports.isAuthError = isAuthError;
function printError(error) {
    return error.message;
}
exports.printError = printError;
//# sourceMappingURL=github.js.map