"use strict";
/*
 * Copyright © 2019 Atomist, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const automation_client_1 = require("@atomist/automation-client");
const _ = require("lodash");
const api_1 = require("./api");
exports.ConvergeRepoOnRepoProvenance = {
    name: "ConvergeRepoOnRepoProvenance",
    description: "Add repo level webhook for newly generated repositories",
    subscription: automation_client_1.GraphQL.subscription("OnSdmRepoProvenance"),
    listener: (e, ctx) => __awaiter(this, void 0, void 0, function* () {
        const push = e.data.SdmRepoProvenance[0];
        const owner = push.repo.owner;
        const repo = push.repo.name;
        const providerId = push.repo.providerId;
        const provider = yield api_1.loadProvider(ctx.graphClient, `${ctx.workspaceId}_${providerId}`);
        const targetConfiguration = _.get(provider, "targetConfiguration") || { orgSpecs: [], repoSpecs: [] };
        const hasOrg = targetConfiguration.orgSpecs.some(o => o === owner);
        const hasRepo = targetConfiguration.repoSpecs.some(r => r.ownerSpec === owner && r.nameSpec === repo);
        if (!hasOrg && !hasRepo) {
            targetConfiguration.repoSpecs.push({ ownerSpec: owner, nameSpec: repo });
            yield ctx.graphClient.mutate({
                name: "ConfigureGitHubScmProvider",
                variables: {
                    id: providerId,
                    orgs: targetConfiguration.orgSpecs,
                    repos: targetConfiguration.repoSpecs.map(r => ({ owner: r.ownerSpec, repo: r.nameSpec })),
                },
            });
        }
        return automation_client_1.Success;
    }),
};
//# sourceMappingURL=repo.js.map