export declare type Maybe<T> = T | null;
export interface ScmResourceProviderInput {
    orgs: string[];
    repos: ScmResourceProviderRepoInput[];
}
export interface ScmResourceProviderRepoInput {
    owner: string;
    repo: string;
}
export interface ResourceProviderStateInput {
    state: ScmProviderStateName;
    error?: Maybe<string>;
}
export interface WebhookInput {
    name: string;
    resourceProviderId: string;
    authType: WebhookAuthType;
    hmacSha1?: Maybe<HmacSha1AuthInput>;
    tags?: Maybe<(Maybe<TagInput>)[]>;
}
export interface HmacSha1AuthInput {
    /** shared secret */
    secret: string;
    /** http header in which to find the hash */
    header?: Maybe<string>;
}
export interface TagInput {
    name: string;
    value: string;
}
/** Enum for IssueState */
export declare enum IssueState {
    open = "open",
    closed = "closed"
}
/** Ordering Enum for Issue */
export declare enum _IssueOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    number_asc = "number_asc",
    number_desc = "number_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    title_asc = "title_asc",
    title_desc = "title_desc",
    body_asc = "body_asc",
    body_desc = "body_desc",
    state_asc = "state_asc",
    state_desc = "state_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc",
    action_asc = "action_asc",
    action_desc = "action_desc",
    createdAt_asc = "createdAt_asc",
    createdAt_desc = "createdAt_desc",
    updatedAt_asc = "updatedAt_asc",
    updatedAt_desc = "updatedAt_desc",
    closedAt_asc = "closedAt_asc",
    closedAt_desc = "closedAt_desc"
}
/** Ordering Enum for Label */
export declare enum _LabelOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    default_asc = "default_asc",
    default_desc = "default_desc",
    color_asc = "color_asc",
    color_desc = "color_desc"
}
/** Ordering Enum for ChatChannel */
export declare enum _ChatChannelOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    provider_asc = "provider_asc",
    provider_desc = "provider_desc",
    normalizedName_asc = "normalizedName_asc",
    normalizedName_desc = "normalizedName_desc",
    channelId_asc = "channelId_asc",
    channelId_desc = "channelId_desc",
    isDefault_asc = "isDefault_asc",
    isDefault_desc = "isDefault_desc",
    botInvitedSelf_asc = "botInvitedSelf_asc",
    botInvitedSelf_desc = "botInvitedSelf_desc",
    archived_asc = "archived_asc",
    archived_desc = "archived_desc"
}
/** Ordering Enum for Email */
export declare enum _EmailOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    address_asc = "address_asc",
    address_desc = "address_desc"
}
/** Ordering Enum for Person */
export declare enum _PersonOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    forename_asc = "forename_asc",
    forename_desc = "forename_desc",
    surname_asc = "surname_asc",
    surname_desc = "surname_desc",
    name_asc = "name_asc",
    name_desc = "name_desc"
}
/** Ordering Enum for Org */
export declare enum _OrgOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    owner_asc = "owner_asc",
    owner_desc = "owner_desc",
    ownerType_asc = "ownerType_asc",
    ownerType_desc = "ownerType_desc"
}
/** Enum for OwnerType */
export declare enum OwnerType {
    user = "user",
    organization = "organization"
}
/** Enum for ProviderType */
export declare enum ProviderType {
    bitbucket_cloud = "bitbucket_cloud",
    github_com = "github_com",
    ghe = "ghe",
    bitbucket = "bitbucket",
    gitlab = "gitlab"
}
export declare enum WebhookAuthType {
    hmac_sha1 = "hmac_sha1",
    none = "none"
}
export declare enum ScmProviderStateName {
    converged = "converged",
    misconfigured = "misconfigured",
    unauthorized = "unauthorized"
}
/** Ordering Enum for Repo */
export declare enum _RepoOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    owner_asc = "owner_asc",
    owner_desc = "owner_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    allowRebaseMerge_asc = "allowRebaseMerge_asc",
    allowRebaseMerge_desc = "allowRebaseMerge_desc",
    allowSquashMerge_asc = "allowSquashMerge_asc",
    allowSquashMerge_desc = "allowSquashMerge_desc",
    allowMergeCommit_asc = "allowMergeCommit_asc",
    allowMergeCommit_desc = "allowMergeCommit_desc",
    repoId_asc = "repoId_asc",
    repoId_desc = "repoId_desc",
    gitHubId_asc = "gitHubId_asc",
    gitHubId_desc = "gitHubId_desc",
    defaultBranch_asc = "defaultBranch_asc",
    defaultBranch_desc = "defaultBranch_desc"
}
/** Ordering Enum for ChatId */
export declare enum _ChatIdOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    screenName_asc = "screenName_asc",
    screenName_desc = "screenName_desc",
    userId_asc = "userId_asc",
    userId_desc = "userId_desc",
    provider_asc = "provider_asc",
    provider_desc = "provider_desc",
    isAtomistBot_asc = "isAtomistBot_asc",
    isAtomistBot_desc = "isAtomistBot_desc",
    isOwner_asc = "isOwner_asc",
    isOwner_desc = "isOwner_desc",
    isPrimaryOwner_asc = "isPrimaryOwner_asc",
    isPrimaryOwner_desc = "isPrimaryOwner_desc",
    isAdmin_asc = "isAdmin_asc",
    isAdmin_desc = "isAdmin_desc",
    isBot_asc = "isBot_asc",
    isBot_desc = "isBot_desc",
    timezoneLabel_asc = "timezoneLabel_asc",
    timezoneLabel_desc = "timezoneLabel_desc"
}
/** Ordering Enum for SCMProvider */
export declare enum _ScmProviderOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    url_asc = "url_asc",
    url_desc = "url_desc",
    providerId_asc = "providerId_asc",
    providerId_desc = "providerId_desc",
    apiUrl_asc = "apiUrl_asc",
    apiUrl_desc = "apiUrl_desc",
    gitUrl_asc = "gitUrl_asc",
    gitUrl_desc = "gitUrl_desc",
    providerType_asc = "providerType_asc",
    providerType_desc = "providerType_desc"
}
/** Ordering Enum for ChatTeam */
export declare enum _ChatTeamOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    provider_asc = "provider_asc",
    provider_desc = "provider_desc",
    domain_asc = "domain_asc",
    domain_desc = "domain_desc",
    messageCount_asc = "messageCount_asc",
    messageCount_desc = "messageCount_desc",
    emailDomain_asc = "emailDomain_asc",
    emailDomain_desc = "emailDomain_desc"
}
/** Ordering Enum for ChannelLink */
export declare enum _ChannelLinkOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc"
}
/** Ordering Enum for PullRequest */
export declare enum _PullRequestOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    number_asc = "number_asc",
    number_desc = "number_desc",
    prId_asc = "prId_asc",
    prId_desc = "prId_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    body_asc = "body_asc",
    body_desc = "body_desc",
    state_asc = "state_asc",
    state_desc = "state_desc",
    merged_asc = "merged_asc",
    merged_desc = "merged_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc",
    baseBranchName_asc = "baseBranchName_asc",
    baseBranchName_desc = "baseBranchName_desc",
    branchName_asc = "branchName_asc",
    branchName_desc = "branchName_desc",
    title_asc = "title_asc",
    title_desc = "title_desc",
    createdAt_asc = "createdAt_asc",
    createdAt_desc = "createdAt_desc",
    updatedAt_asc = "updatedAt_asc",
    updatedAt_desc = "updatedAt_desc",
    closedAt_asc = "closedAt_asc",
    closedAt_desc = "closedAt_desc",
    mergedAt_asc = "mergedAt_asc",
    mergedAt_desc = "mergedAt_desc",
    mergeStatus_asc = "mergeStatus_asc",
    mergeStatus_desc = "mergeStatus_desc"
}
/** Enum for MergeStatus */
export declare enum MergeStatus {
    can_be_merged = "can_be_merged",
    unchecked = "unchecked",
    cannot_be_merged = "cannot_be_merged"
}
export declare enum PullRequestAction {
    assigned = "assigned",
    created = "created",
    unassigned = "unassigned",
    review_requested = "review_requested",
    review_request_removed = "review_request_removed",
    labeled = "labeled",
    unlabeled = "unlabeled",
    opened = "opened",
    edited = "edited",
    closed = "closed",
    reopened = "reopened",
    synchronize = "synchronize",
    submitted = "submitted"
}
/** Enum for BuildStatus */
export declare enum BuildStatus {
    passed = "passed",
    broken = "broken",
    failed = "failed",
    started = "started",
    canceled = "canceled",
    pending = "pending"
}
/** Enum for BuildTrigger */
export declare enum BuildTrigger {
    pull_request = "pull_request",
    push = "push",
    tag = "tag",
    cron = "cron"
}
/** Ordering Enum for Build */
export declare enum _BuildOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    buildId_asc = "buildId_asc",
    buildId_desc = "buildId_desc",
    number_asc = "number_asc",
    number_desc = "number_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    status_asc = "status_asc",
    status_desc = "status_desc",
    buildUrl_asc = "buildUrl_asc",
    buildUrl_desc = "buildUrl_desc",
    compareUrl_asc = "compareUrl_asc",
    compareUrl_desc = "compareUrl_desc",
    trigger_asc = "trigger_asc",
    trigger_desc = "trigger_desc",
    provider_asc = "provider_asc",
    provider_desc = "provider_desc",
    pullRequestNumber_asc = "pullRequestNumber_asc",
    pullRequestNumber_desc = "pullRequestNumber_desc",
    startedAt_asc = "startedAt_asc",
    startedAt_desc = "startedAt_desc",
    finishedAt_asc = "finishedAt_asc",
    finishedAt_desc = "finishedAt_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc",
    workflowId_asc = "workflowId_asc",
    workflowId_desc = "workflowId_desc",
    jobName_asc = "jobName_asc",
    jobName_desc = "jobName_desc",
    jobId_asc = "jobId_asc",
    jobId_desc = "jobId_desc",
    data_asc = "data_asc",
    data_desc = "data_desc"
}
/** Ordering Enum for Commit */
export declare enum _CommitOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    sha_asc = "sha_asc",
    sha_desc = "sha_desc",
    message_asc = "message_asc",
    message_desc = "message_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc"
}
/** Enum for PipelineStatus */
export declare enum PipelineStatus {
    running = "running",
    pending = "pending",
    success = "success",
    failed = "failed",
    canceled = "canceled",
    skipped = "skipped",
    manual = "manual"
}
/** Enum for the PipelineProviders */
export declare enum PipelineProvider {
    gitlab_ci = "gitlab_ci"
}
/** Enum for JobStatus */
export declare enum JobStatus {
    created = "created",
    pending = "pending",
    running = "running",
    failed = "failed",
    success = "success",
    canceled = "canceled",
    skipped = "skipped",
    manual = "manual"
}
export declare enum SdmGoalState {
    success = "success",
    pre_approved = "pre_approved",
    requested = "requested",
    waiting_for_pre_approval = "waiting_for_pre_approval",
    approved = "approved",
    waiting_for_approval = "waiting_for_approval",
    failure = "failure",
    stopped = "stopped",
    planned = "planned",
    in_process = "in_process",
    skipped = "skipped",
    canceled = "canceled"
}
export declare enum SdmGoalDisplayState {
    show_current = "show_current",
    show_all = "show_all"
}
/** Ordering Enum for DockerImage */
export declare enum _DockerImageOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    image_asc = "image_asc",
    image_desc = "image_desc",
    imageName_asc = "imageName_asc",
    imageName_desc = "imageName_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc"
}
/** Ordering Enum for K8Pod */
export declare enum _K8PodOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    phase_asc = "phase_asc",
    phase_desc = "phase_desc",
    environment_asc = "environment_asc",
    environment_desc = "environment_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc",
    baseName_asc = "baseName_asc",
    baseName_desc = "baseName_desc",
    namespace_asc = "namespace_asc",
    namespace_desc = "namespace_desc",
    statusJSON_asc = "statusJSON_asc",
    statusJSON_desc = "statusJSON_desc",
    host_asc = "host_asc",
    host_desc = "host_desc",
    state_asc = "state_asc",
    state_desc = "state_desc",
    specsJSON_asc = "specsJSON_asc",
    specsJSON_desc = "specsJSON_desc",
    envJSON_asc = "envJSON_asc",
    envJSON_desc = "envJSON_desc",
    metadataJSON_asc = "metadataJSON_asc",
    metadataJSON_desc = "metadataJSON_desc",
    containersCrashLoopBackOff_asc = "containersCrashLoopBackOff_asc",
    containersCrashLoopBackOff_desc = "containersCrashLoopBackOff_desc",
    resourceVersion_asc = "resourceVersion_asc",
    resourceVersion_desc = "resourceVersion_desc"
}
/** Ordering Enum for K8Container */
export declare enum _K8ContainerOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    imageName_asc = "imageName_asc",
    imageName_desc = "imageName_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc",
    environment_asc = "environment_asc",
    environment_desc = "environment_desc",
    containerJSON_asc = "containerJSON_asc",
    containerJSON_desc = "containerJSON_desc",
    state_asc = "state_asc",
    state_desc = "state_desc",
    stateReason_asc = "stateReason_asc",
    stateReason_desc = "stateReason_desc",
    ready_asc = "ready_asc",
    ready_desc = "ready_desc",
    restartCount_asc = "restartCount_asc",
    restartCount_desc = "restartCount_desc",
    statusJSON_asc = "statusJSON_asc",
    statusJSON_desc = "statusJSON_desc",
    resourceVersion_asc = "resourceVersion_asc",
    resourceVersion_desc = "resourceVersion_desc",
    containerID_asc = "containerID_asc",
    containerID_desc = "containerID_desc"
}
/** Ordering Enum for Tag */
export declare enum _TagOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    description_asc = "description_asc",
    description_desc = "description_desc",
    ref_asc = "ref_asc",
    ref_desc = "ref_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc"
}
/** Enum for StatusState */
export declare enum StatusState {
    pending = "pending",
    success = "success",
    error = "error",
    failure = "failure"
}
/** Ordering Enum for Status */
export declare enum _StatusOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    state_asc = "state_asc",
    state_desc = "state_desc",
    description_asc = "description_asc",
    description_desc = "description_desc",
    targetUrl_asc = "targetUrl_asc",
    targetUrl_desc = "targetUrl_desc",
    context_asc = "context_asc",
    context_desc = "context_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc"
}
/** Ordering Enum for Push */
export declare enum _PushOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc",
    branch_asc = "branch_asc",
    branch_desc = "branch_desc"
}
/** Ordering Enum for HerokuApp */
export declare enum _HerokuAppOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    app_asc = "app_asc",
    app_desc = "app_desc",
    url_asc = "url_asc",
    url_desc = "url_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc",
    user_asc = "user_asc",
    user_desc = "user_desc",
    appId_asc = "appId_asc",
    appId_desc = "appId_desc",
    release_asc = "release_asc",
    release_desc = "release_desc"
}
/** Ordering Enum for Application */
export declare enum _ApplicationOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    state_asc = "state_asc",
    state_desc = "state_desc",
    host_asc = "host_asc",
    host_desc = "host_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc",
    domain_asc = "domain_asc",
    domain_desc = "domain_desc",
    data_asc = "data_asc",
    data_desc = "data_desc"
}
/** Ordering Enum for Fingerprint */
export declare enum _FingerprintOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    sha_asc = "sha_asc",
    sha_desc = "sha_desc",
    data_asc = "data_asc",
    data_desc = "data_desc"
}
/** Ordering Enum for SCMId */
export declare enum _ScmIdOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    login_asc = "login_asc",
    login_desc = "login_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    avatar_asc = "avatar_asc",
    avatar_desc = "avatar_desc"
}
/** Enum for ReviewState */
export declare enum ReviewState {
    requested = "requested",
    pending = "pending",
    approved = "approved",
    commented = "commented",
    unapproved = "unapproved",
    changes_requested = "changes_requested"
}
/** Ordering Enum for Review */
export declare enum _ReviewOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    gitHubId_asc = "gitHubId_asc",
    gitHubId_desc = "gitHubId_desc",
    reviewId_asc = "reviewId_asc",
    reviewId_desc = "reviewId_desc",
    body_asc = "body_asc",
    body_desc = "body_desc",
    state_asc = "state_asc",
    state_desc = "state_desc",
    submittedAt_asc = "submittedAt_asc",
    submittedAt_desc = "submittedAt_desc",
    htmlUrl_asc = "htmlUrl_asc",
    htmlUrl_desc = "htmlUrl_desc"
}
/** Ordering Enum for Comment */
export declare enum _CommentOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    body_asc = "body_asc",
    body_desc = "body_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc",
    createdAt_asc = "createdAt_asc",
    createdAt_desc = "createdAt_desc",
    updatedAt_asc = "updatedAt_asc",
    updatedAt_desc = "updatedAt_desc",
    commentId_asc = "commentId_asc",
    commentId_desc = "commentId_desc",
    gitHubId_asc = "gitHubId_asc",
    gitHubId_desc = "gitHubId_desc",
    path_asc = "path_asc",
    path_desc = "path_desc",
    position_asc = "position_asc",
    position_desc = "position_desc",
    htmlUrl_asc = "htmlUrl_asc",
    htmlUrl_desc = "htmlUrl_desc",
    commentType_asc = "commentType_asc",
    commentType_desc = "commentType_desc"
}
/** Enum for CommentCommentType */
export declare enum CommentCommentType {
    review = "review",
    pullRequest = "pullRequest",
    issue = "issue"
}
/** Ordering Enum for Branch */
export declare enum _BranchOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc",
    isRemote_asc = "isRemote_asc",
    isRemote_desc = "isRemote_desc",
    remoteRepoHtmlUrl_asc = "remoteRepoHtmlUrl_asc",
    remoteRepoHtmlUrl_desc = "remoteRepoHtmlUrl_desc"
}
/** Ordering Enum for Workflow */
export declare enum _WorkflowOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    workflowId_asc = "workflowId_asc",
    workflowId_desc = "workflowId_desc",
    provider_asc = "provider_asc",
    provider_desc = "provider_desc",
    config_asc = "config_asc",
    config_desc = "config_desc"
}
/** Ordering Enum for DeletedBranch */
export declare enum _DeletedBranchOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc"
}
/** Ordering Enum for GitHubId */
export declare enum _GitHubIdOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    login_asc = "login_asc",
    login_desc = "login_desc",
    name_asc = "name_asc",
    name_desc = "name_desc"
}
/** Ordering Enum for ImageLinked */
export declare enum _ImageLinkedOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc"
}
/** Ordering Enum for Release */
export declare enum _ReleaseOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    timestamp_asc = "timestamp_asc",
    timestamp_desc = "timestamp_desc"
}
/** Ordering Enum for Team */
export declare enum _TeamOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    name_asc = "name_asc",
    name_desc = "name_desc",
    description_asc = "description_asc",
    description_desc = "description_desc",
    iconUrl_asc = "iconUrl_asc",
    iconUrl_desc = "iconUrl_desc",
    createdAt_asc = "createdAt_asc",
    createdAt_desc = "createdAt_desc"
}
/** Ordering Enum for ParentImpact */
export declare enum _ParentImpactOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    url_asc = "url_asc",
    url_desc = "url_desc",
    data_asc = "data_asc",
    data_desc = "data_desc"
}
/** Ordering Enum for PushImpact */
export declare enum _PushImpactOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    url_asc = "url_asc",
    url_desc = "url_desc",
    data_asc = "data_asc",
    data_desc = "data_desc"
}
/** Ordering Enum for PullRequestImpact */
export declare enum _PullRequestImpactOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    url_asc = "url_asc",
    url_desc = "url_desc",
    data_asc = "data_asc",
    data_desc = "data_desc"
}
/** Ordering Enum for GitHubProvider */
export declare enum _GitHubProviderOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc",
    url_asc = "url_asc",
    url_desc = "url_desc",
    providerId_asc = "providerId_asc",
    providerId_desc = "providerId_desc",
    apiUrl_asc = "apiUrl_asc",
    apiUrl_desc = "apiUrl_desc",
    gitUrl_asc = "gitUrl_asc",
    gitUrl_desc = "gitUrl_desc",
    providerType_asc = "providerType_asc",
    providerType_desc = "providerType_desc"
}
/** Ordering Enum for UserJoinedChannel */
export declare enum _UserJoinedChannelOrdering {
    atmTeamId_asc = "atmTeamId_asc",
    atmTeamId_desc = "atmTeamId_desc",
    id_asc = "id_asc",
    id_desc = "id_desc"
}
/** asc or desc ordering. Must be used with orderBy */
export declare enum _Ordering {
    desc = "desc",
    asc = "asc"
}
export declare enum CommitIssueRelationshipType {
    references = "references",
    fixes = "fixes"
}
export declare enum SdmDeployState {
    requested = "requested",
    disabled = "disabled"
}
export declare namespace AddWebhookTag {
    type Variables = {
        id: string;
        name: string;
        value: string;
    };
    type Mutation = {
        __typename?: "Mutation";
        addWebhookTag?: AddWebhookTag;
    };
    type AddWebhookTag = {
        __typename?: "Webhook";
        id?: string;
    };
}
export declare namespace ConfigureGitHubScmProvider {
    type Variables = {
        id: string;
        orgs: string[];
        repos: ScmResourceProviderRepoInput[];
    };
    type Mutation = {
        __typename?: "Mutation";
        configureGitHubResourceProvider?: ConfigureGitHubResourceProvider;
    };
    type ConfigureGitHubResourceProvider = {
        __typename?: "SCMProvider";
        id?: string;
    };
}
export declare namespace CreateWebhook {
    type Variables = {
        resourceProviderId: string;
        secret: string;
        header: string;
        name: string;
        tags?: Maybe<(Maybe<TagInput>)[]>;
    };
    type Mutation = {
        __typename?: "Mutation";
        createWebhook?: CreateWebhook;
    };
    type CreateWebhook = {
        __typename?: "Webhook";
        url?: string;
        id?: string;
    };
}
export declare namespace DeleteWebhook {
    type Variables = {
        id: string;
    };
    type Mutation = {
        __typename?: "Mutation";
        deleteWebhook?: string;
    };
}
export declare namespace SetOwnerLogin {
    type Variables = {
        providerId: string;
        owner: string;
        login: string;
    };
    type Mutation = {
        __typename?: "Mutation";
        setOwnerLogin?: Maybe<SetOwnerLogin>;
    };
    type SetOwnerLogin = {
        __typename?: "OwnerLogin";
        login?: Maybe<string>;
    };
}
export declare namespace SetRepoLogin {
    type Variables = {
        providerId: string;
        repo: string;
        owner: string;
        login: string;
    };
    type Mutation = {
        __typename?: "Mutation";
        setRepoLogin?: Maybe<SetRepoLogin>;
    };
    type SetRepoLogin = {
        __typename?: "RepoLogin";
        login?: Maybe<string>;
    };
}
export declare namespace SetScmProviderState {
    type Variables = {
        id: string;
        state: ScmProviderStateName;
        error?: Maybe<string>;
    };
    type Mutation = {
        __typename?: "Mutation";
        setSCMProviderState?: SetScmProviderState;
    };
    type SetScmProviderState = {
        __typename?: "SCMProvider";
        id?: string;
    };
}
export declare namespace ScmProvider {
    type Variables = {
        type: ProviderType;
    };
    type Query = {
        __typename?: "Query";
        SCMProvider?: Maybe<(Maybe<ScmProvider>)[]>;
    };
    type ScmProvider = {
        __typename?: "SCMProvider";
        apiUrl?: Maybe<string>;
        url?: Maybe<string>;
        gitUrl?: Maybe<string>;
        providerType?: Maybe<ProviderType>;
        id?: string;
        providerId?: Maybe<string>;
        name?: Maybe<string>;
        targetConfiguration?: Maybe<TargetConfiguration>;
        state?: Maybe<State>;
        authProviderId?: Maybe<string>;
        credential?: Maybe<Credential>;
        webhooks?: Maybe<(Maybe<Webhooks>)[]>;
    };
    type TargetConfiguration = {
        __typename?: "SCMProviderSpec";
        orgSpecs?: string[];
        repoSpecs?: RepoSpecs[];
    };
    type RepoSpecs = {
        __typename?: "SCMProviderRepoSpec";
        ownerSpec?: string;
        nameSpec?: string;
    };
    type State = {
        __typename?: "SCMProviderState";
        error?: Maybe<string>;
        name?: Maybe<ScmProviderStateName>;
    };
    type Credential = {
        __typename?: "OAuthToken";
        scopes?: string[];
        secret?: string;
        owner?: Owner;
    };
    type Owner = {
        __typename?: "SCMId";
        person?: Maybe<Person>;
    };
    type Person = {
        __typename?: "Person";
        scmId?: Maybe<ScmId>;
    };
    type ScmId = {
        __typename?: "SCMId";
        login?: Maybe<string>;
    };
    type Webhooks = {
        __typename?: "Webhook";
        id?: string;
        url?: string;
        tags?: Maybe<(Maybe<Tags>)[]>;
    };
    type Tags = {
        __typename?: "AtomistKeyValuePair";
        name?: string;
        value?: string;
    };
}
export declare namespace ScmProviderById {
    type Variables = {
        id: string;
    };
    type Query = {
        __typename?: "Query";
        SCMProvider?: Maybe<(Maybe<ScmProvider>)[]>;
    };
    type ScmProvider = {
        __typename?: "SCMProvider";
        apiUrl?: Maybe<string>;
        url?: Maybe<string>;
        gitUrl?: Maybe<string>;
        providerType?: Maybe<ProviderType>;
        id?: string;
        providerId?: Maybe<string>;
        name?: Maybe<string>;
        targetConfiguration?: Maybe<TargetConfiguration>;
        state?: Maybe<State>;
        authProviderId?: Maybe<string>;
        credential?: Maybe<Credential>;
        webhooks?: Maybe<(Maybe<Webhooks>)[]>;
    };
    type TargetConfiguration = {
        __typename?: "SCMProviderSpec";
        orgSpecs?: string[];
        repoSpecs?: RepoSpecs[];
    };
    type RepoSpecs = {
        __typename?: "SCMProviderRepoSpec";
        ownerSpec?: string;
        nameSpec?: string;
    };
    type State = {
        __typename?: "SCMProviderState";
        error?: Maybe<string>;
        name?: Maybe<ScmProviderStateName>;
    };
    type Credential = {
        __typename?: "OAuthToken";
        scopes?: string[];
        secret?: string;
        owner?: Owner;
    };
    type Owner = {
        __typename?: "SCMId";
        person?: Maybe<Person>;
    };
    type Person = {
        __typename?: "Person";
        scmId?: Maybe<ScmId>;
    };
    type ScmId = {
        __typename?: "SCMId";
        login?: Maybe<string>;
    };
    type Webhooks = {
        __typename?: "Webhook";
        id?: string;
        url?: string;
        tags?: Maybe<(Maybe<Tags>)[]>;
    };
    type Tags = {
        __typename?: "AtomistKeyValuePair";
        name?: string;
        value?: string;
    };
}
export declare namespace OnScmProvider {
    type Variables = {
        type: ProviderType;
    };
    type Subscription = {
        __typename?: "Subscription";
        SCMProvider?: Maybe<(Maybe<ScmProvider>)[]>;
    };
    type ScmProvider = {
        __typename?: "SCMProvider";
        apiUrl?: Maybe<string>;
        url?: Maybe<string>;
        gitUrl?: Maybe<string>;
        providerType?: Maybe<ProviderType>;
        id?: string;
        providerId?: Maybe<string>;
        name?: Maybe<string>;
        targetConfiguration?: Maybe<TargetConfiguration>;
        state?: Maybe<State>;
        authProviderId?: Maybe<string>;
        credential?: Maybe<Credential>;
        webhooks?: Maybe<(Maybe<Webhooks>)[]>;
    };
    type TargetConfiguration = {
        __typename?: "SCMProviderSpec";
        orgSpecs?: string[];
        repoSpecs?: RepoSpecs[];
    };
    type RepoSpecs = {
        __typename?: "SCMProviderRepoSpec";
        ownerSpec?: string;
        nameSpec?: string;
    };
    type State = {
        __typename?: "SCMProviderState";
        error?: Maybe<string>;
        name?: Maybe<ScmProviderStateName>;
    };
    type Credential = {
        __typename?: "OAuthToken";
        scopes?: string[];
        secret?: string;
        owner?: Owner;
    };
    type Owner = {
        __typename?: "SCMId";
        person?: Maybe<Person>;
    };
    type Person = {
        __typename?: "Person";
        scmId?: Maybe<ScmId>;
    };
    type ScmId = {
        __typename?: "SCMId";
        login?: Maybe<string>;
    };
    type Webhooks = {
        __typename?: "Webhook";
        id?: string;
        url?: string;
        tags?: Maybe<(Maybe<Tags>)[]>;
    };
    type Tags = {
        __typename?: "AtomistKeyValuePair";
        name?: string;
        value?: string;
    };
}
export declare namespace OnSdmRepoProvenance {
    type Variables = {};
    type Subscription = {
        __typename?: "Subscription";
        SdmRepoProvenance?: Maybe<(Maybe<SdmRepoProvenance>)[]>;
    };
    type SdmRepoProvenance = {
        __typename?: "SdmRepoProvenance";
        repo?: Maybe<Repo>;
    };
    type Repo = {
        __typename?: "SdmRepository";
        name?: Maybe<string>;
        owner?: Maybe<string>;
        providerId?: Maybe<string>;
    };
}
