"use strict";
/*
 * Copyright © 2018 Atomist, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const automation_client_1 = require("@atomist/automation-client");
const AbstractActivityFeedEventReader_1 = require("./support/AbstractActivityFeedEventReader");
class GitHubActivityFeedEventReader extends AbstractActivityFeedEventReader_1.AbstractActivityFeedEventReader {
    constructor(criteria, token, configuration) {
        super(criteria);
        this.criteria = criteria;
        this.token = token;
        this.configuration = configuration;
    }
    /**
     * Read the GitHub activity feed
     * @return {Promise<void>}
     */
    // TODO can get a CreateEvent also,
    readNewEvents() {
        return __awaiter(this, void 0, void 0, function* () {
            // TODO how many events do you get
            const url = `${this.criteria.apiUrl || "api.github.com"}/${!!this.criteria.user ? "users" : "orgs"}/${this.criteria.owner}/events`;
            const client = this.configuration.http.client.factory.create(url);
            const r = yield client.exchange(url, {
                method: automation_client_1.HttpMethod.Get,
                headers: {
                    Authorization: `token ${this.token}`,
                },
            });
            const eventsRead = r.body;
            const newEvents = eventsRead
                .map(toFeedEvent)
                .filter(e => !this.eventWindow.some(seen => seen.id === e.id));
            this.eventWindow.push(...newEvents);
            automation_client_1.logger.debug(JSON.stringify(newEvents));
            return newEvents;
        });
    }
}
exports.GitHubActivityFeedEventReader = GitHubActivityFeedEventReader;
function toFeedEvent(e) {
    // name is of form owner/name
    if (!!e.repo) {
        const elts = e.repo.name.split("/");
        e.repo.owner = elts[0];
        e.repo.repo = elts[1];
    }
    e.head = e.payload.head;
    e.ref = e.payload.ref;
    return e;
}
//# sourceMappingURL=GitHubActivityFeedEventReader.js.map