"use strict";
/*
 * Copyright © 2018 Atomist, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const automation_client_1 = require("@atomist/automation-client");
const sdm_1 = require("@atomist/sdm");
const expandedTreeUtils_1 = require("@atomist/sdm-local/lib/sdm/binding/project/expandedTreeUtils");
const fs = require("fs-extra");
const FeedEvent_1 = require("./FeedEvent");
/**
 * Start watching this remote org
 * @param {ScmFeedCriteria} criteria
 * @return {Promise<void>}
 */
function startWatching(criteria, setup, sdm) {
    if (criteria.owner && criteria.owner.length > 0) {
        sdm.addStartupListener(() => __awaiter(this, void 0, void 0, function* () { return setup.feedEventReader.start(); }));
        sdm.addTriggeredListener({
            trigger: {
                interval: setup.interval,
            },
            listener: () => __awaiter(this, void 0, void 0, function* () {
                try {
                    automation_client_1.logger.info("Reading SCM activity feed for '%s'", criteria.owner);
                    const newEvents = (yield setup.feedEventReader.readNewEvents())
                        .filter(FeedEvent_1.isRelevantEvent);
                    yield updateClonedProjects(criteria, newEvents, setup.repositoryOwnerParentDirectory);
                    automation_client_1.logger.info("Finished reading SCM activity feed for '%s'", criteria.owner);
                }
                catch (e) {
                    automation_client_1.logger.error("Error attempting to poll SCM provider: %s", e.message);
                }
            }),
        });
    }
}
exports.startWatching = startWatching;
/**
 * Update projects based on commit criteria
 */
function updateClonedProjects(criteria, feedEvents, repositoryOwnerParentDirectory) {
    return __awaiter(this, void 0, void 0, function* () {
        for (const pushEvent of feedEvents) {
            // Update to events
            const dir = expandedTreeUtils_1.dirFor(repositoryOwnerParentDirectory, pushEvent.repo.owner, pushEvent.repo.repo);
            if (fs.existsSync(dir)) {
                automation_client_1.logger.info("Updating project '%s/%s' at directory '%s'", pushEvent.repo.owner, pushEvent.repo.repo, dir);
                const result = yield sdm_1.execPromise("git", ["pull"], { cwd: dir });
                if (result.stdout) {
                    automation_client_1.logger.debug(result.stdout);
                }
                if (result.stderr) {
                    automation_client_1.logger.debug(result.stderr);
                }
            }
            else {
                automation_client_1.logger.info("Ignoring push to un-managed project '%s/%s'. Expected directory does not exist '%s'", pushEvent.repo.owner, pushEvent.repo.repo, dir);
            }
        }
    });
}
//# sourceMappingURL=watcher.js.map