"use strict";
/*
 * Copyright © 2018 Atomist, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const automation_client_1 = require("@atomist/automation-client");
const sdm_1 = require("@atomist/sdm");
const sdm_core_1 = require("@atomist/sdm-core");
const defaultLocalSoftwareDeliveryMachineConfiguration_1 = require("@atomist/sdm-local/lib/sdm/configuration/defaultLocalSoftwareDeliveryMachineConfiguration");
const _ = require("lodash");
const GitHubActivityFeedEventReader_1 = require("./GitHubActivityFeedEventReader");
const watcher_1 = require("./support/watcher");
function watchGitHub(options = {}) {
    return Object.assign({}, sdm_1.metadata("watch"), { requiredConfigurationValues: [
        // TODO CD make optional configuration values work
        /*{
            path: "sdm.watch.github.owner",
            type: ConfigurationValueType.String,
        },*/
        ], configure: sdm => {
            if (!sdm_core_1.isInLocalMode()) {
                return;
            }
            const optsToUse = Object.assign({ token: _.get(sdm, "configuration.sdm.watch.github.token") || _.get(sdm, "configuration.token"), owner: _.get(sdm, "configuration.sdm.watch.github.owner", []), user: _.get(sdm, "configuration.sdm.watch.github.user", false), interval: _.get(sdm, "configuration.sdm.watch.github.interval", 1000 * 10), apiUrl: _.get(sdm, "configuration.sdm.watch.github.apiUrl", "https://api.github.com") }, options);
            const owners = automation_client_1.toStringArray(optsToUse.owner);
            for (const owner of owners) {
                const criteria = {
                    owner,
                    user: optsToUse.user,
                    apiUrl: optsToUse.apiUrl,
                };
                const feedEventReader = new GitHubActivityFeedEventReader_1.GitHubActivityFeedEventReader(criteria, optsToUse.token, sdm.configuration);
                watcher_1.startWatching(criteria, {
                    repositoryOwnerParentDirectory: defaultLocalSoftwareDeliveryMachineConfiguration_1.determineDefaultRepositoryOwnerParentDirectory(),
                    interval: optsToUse.interval,
                    feedEventReader,
                }, sdm);
            }
        } });
}
exports.watchGitHub = watchGitHub;
//# sourceMappingURL=watchGitHub.js.map